@@ -2,6 +2,7 @@ from arc.middleware import Middleware
 from arc.defaults import DefaultMiddleware, DefaultExceptionHandler
 from jinja2.loaders import FileSystemLoader
 from starlette.requests import Request
+from starlette.staticfiles import StaticFiles
 import uvicorn
 from parse import parse
 from jinja2 import Environment, FileSystemLoader
@@ -96,6 +97,8 @@ class App:
 
         self.whitenoise = WhiteNoise(self.wsgi_app, root=static_dir)
 
+        self.static_app = StaticFiles(directory=static_dir)
+
         self.middleware = Middleware(self)
 
         if default_middleware:
@@ -113,9 +116,9 @@ class App:
     async def __call__(self, scope, recieve, send):
         path_info = scope["path"]
 
-        # if path_info.startswith("/static") or path_info.startswith("static"):
-        #     scope["PATH_INFO"] = path_info[len("/static"):]
-        #     return self.whitenoise(environ, start_response)
+        if path_info.startswith("/static") or path_info.startswith("static"):
+            scope["PATH_INFO"] = path_info[len("/static"):]
+            return self.static_app(scope, recieve, send)
 
         await self.middleware(scope, recieve, send)
 
@@ -132,7 +135,7 @@ class App:
 
                 response = handler(request, **kwargs)
             else:
-                self.default_response()
+                response = self.default_response()
 
         except Exception as e:
             error = traceback.format_exc()
